# utils
Various utility modules shared amongst several projects in the 4DN-DCIC.

pip installable with: `pip install dcicutils`

[![Build Status](https://travis-ci.org/4dn-dcic/utils.svg?branch=master)](https://travis-ci.org/4dn-dcic/utils)
[![Coverage](https://coveralls.io/repos/github/4dn-dcic/utils/badge.svg?branch=master)](https://coveralls.io/github/4dn-dcic/utils?branch=master)
